angular
  .module('spgTpl1')
  .directive('uploader', function (envService, ArquivosService, Notification, ModalService) {
    return {
      restrict: 'E',
      scope: {
        boxName: '@',
        btnName: '@',
        files: '=',
        anexados: '=',
        tipo: '@', //processos || documentos
        tipoId: '=',
        onlyView: '=',
        tiposPermitidos: '=',
        addClass: '@'
      },
      controller: function ($scope) {
        var vm = this,
          envVars = envService.read('all'),
          _allowFileTypes = ['pdf', 'doc', 'png', 'jpg', 'gif'],
          _maxFileSize = 20;

        vm.apiSigepArquivos = envVars.apiSigepArquivos;
        vm.boxName = ($scope.boxName) ? $scope.boxName : 'Arquivos';
        vm.btnName = ($scope.btnName) ? $scope.btnName : 'Selecione os arquivos';
        vm.addClass = ($scope.addClass) ? $scope.addClass : '';

        if($scope.tiposPermitidos && $scope.tiposPermitidos.length){
          _allowFileTypes = $scope.tiposPermitidos;
        }

        function _allowSize(size){
          return ( (size / (1024*1000)) <= _maxFileSize ) ? true : false;
        };

        vm.uploadFiles = function (files) {
          var _allowedFiles = [];

          angular.forEach(files, function (file) {
            var _typeAccepted = false,
              _sizeAccepted = false;

            angular.forEach(_allowFileTypes, function (ft) {
              if (file.name.lastIndexOf('.'+ft) > -1 && file.name.indexOf('.exe') === -1) {
                _typeAccepted = true;

                if(_allowSize(file.size)) {
                  _allowedFiles.push(file);
                  _sizeAccepted = true;
                }
              }
            });

            if (!_typeAccepted) {
              Notification.error('O arquivo ' + file.name + ' foi bloqueado.');
            }
            if (!_sizeAccepted) {
              Notification.error('O tamanho do aquivo ultrapassou o limite de '+_maxFileSize+'MB.');
            }
          });

          if (vm.files) {
            angular.forEach(_allowedFiles, function (file) {
              vm.files.push(file);
            });
          }
          else if (_allowedFiles && _allowedFiles.length) {
            vm.files = files;

            $scope.files = vm.files;
          }
        };

        vm.removeFile = function (file) {
          vm.files = _.remove(vm.files, function (f) {
            return f.$$hashKey != file.$$hashKey;
          });

          $scope.files = vm.files;
        };

        vm.deleteFile = function (file) {
          ModalService.remove(file.id, file.nome, function(){
            if ($scope.tipo === 'processos') {
              ArquivosService.processos.remove({ processoId: $scope.tipoId, arquivoId: file.id}).$promise.then(function () {
                _removeItem(file);
                Notification.success("Arquivo "+file.nome+" removido com sucesso!");
              });

            } else {
              ArquivosService.documentos.remove({ documentoId: $scope.tipoId, arquivoId: file.id}).$promise.then(function () {
                _removeItem(file);
                Notification.success("Arquivo "+file.nome+" removido com sucesso!");
              });
            }
          });
        };

        function _removeItem(file) {
          $scope.anexados = _.remove($scope.anexados, function (f) {
            return f.$$hashKey != file.$$hashKey;
          });
        }
      },
      controllerAs: 'ctrl',
      templateUrl: "app/system/components/uploader/uploader.html"
    };
  });
