angular
  .module('spgTpl1')
  .factory('AuthService', function($http, $q, $window, envService, $state, $rootScope, base64Service) {
    var envVars = envService.read('all'),
      session = $window.localStorage;

    function login(credentials) {
      var deferred = $q.defer();
      var _authData = 'Basic '+ base64Service.encode(credentials.username +':'+credentials.password);

      $http.post(envVars.apiSigep + '/login', credentials).then(function(response) {
          $http.defaults.headers.common.Authorization = _authData;

          if(!response.data.error) {
            var userInfo = response.data,
              newPermissoes = [];

            userInfo.usuarioPerfis.forEach(function(upObj){
              upObj.perfil.perfilPermissoes.forEach(function(obj){
                newPermissoes.push(obj.permissao.nome.toLowerCase());
              });
            });
            userInfo.permissoes = newPermissoes;
            userInfo.token = _authData;

            session.setItem('userInfo', JSON.stringify(userInfo));
            $rootScope.sessionUser = userInfo;
            setPermissions($rootScope.sessionUser.permissoes);

            deferred.resolve(userInfo);
          }
        },
        function(error){
          deferred.resolve(error);
        }
      );

      return deferred.promise;
    }

    function setPermissions (sessionUserPermissoes){
      $rootScope.checkUserPermission = function(arrPermissions){
        var hasPermission = false;

        arrPermissions.forEach(function(obj){
          if(sessionUserPermissoes.indexOf(obj) > -1 ){
            hasPermission = true;
          }
        });

        return hasPermission;
      };
    }

    function getUserInfo() {
      if (session.userInfo) {
        $rootScope.sessionUser = JSON.parse(session.userInfo);
        setPermissions($rootScope.sessionUser.permissoes);
      } else {
        return false;
      }
    }

    function hasSessionUser() {
      if (session.userInfo) {
        getUserInfo();
        return true;
      } else {
        return false;
      }
    }

    function logout() {
      $http.post(envVars.apiSigep + '/logout', {}, {
        headers: {
          'Content-Type': 'application/json'
        }
      }).then(function(response){
        session.clear();
        $rootScope.sessionUser = undefined;
        $rootScope.authenticated = false;
        $state.go('home');
      }, function(error){
        console.log('error', error)
      });
    }

    return {
      login: login,
      logout: logout,
      getUserInfo: getUserInfo,
      hasSessionUser: hasSessionUser
    };
  });
